@@ -1,4 +1,4 @@
-// # pragma once
+# pragma once
 // # include <Rcpp.h>
 # define eps 1e-10
 # define relaEps 1e-5
@@ -6,5 +6,8 @@
 // # define infy 1e308
 # define word double
 # define INT std::size_t
+# define sINT std::int64_t
 // # define bsiz 64
 # define infinity 1e30
+
+
